@@ -3,10 +3,10 @@ import logging.config
 from typing import Tuple
 
 import tryceratops
-from tryceratops.analyzers import Runner
 from tryceratops.files import FileDiscovery, load_config
-from tryceratops.filters import GlobalFilter
+from tryceratops.filters import GlobalSettings
 from tryceratops.interfaces import CliInterface
+from tryceratops.runners import Runner
 from tryceratops.settings import LOGGING_CONFIG
 from tryceratops.violations import CODE_CHOICES
 
@@ -17,6 +17,9 @@ logger = logging.getLogger("tryceratops")
 
 
 EXPERIMENTAL_FLAG_OPTION = dict(is_flag=True, help="Whether to enable experimental analyzers.")
+AUTOFIX_FLAG_OPTION = dict(
+    is_flag=True, help="Whether to fix violations (that support it) automatically."
+)
 IGNORE_OPTION = dict(
     multiple=True,
     help="A violation to be ignored. e.g. -i TC200 -i TC201",
@@ -32,6 +35,7 @@ VERBOSE_OPTION = dict(is_flag=True, help="Will print more logging messages.")
 @click.option("-i", "--ignore", **IGNORE_OPTION)
 @click.option("-x", "--exclude", **EXCLUDE_OPTION)
 @click.option("-v", "--verbose", **VERBOSE_OPTION)
+@click.option("-a", "--autofix", **AUTOFIX_FLAG_OPTION)
 @click.version_option(tryceratops.__version__)
 def entrypoint(
     dir: Tuple[str],
@@ -39,20 +43,21 @@ def entrypoint(
     ignore: Tuple[str, ...],
     exclude: Tuple[str, ...],
     verbose: bool,
+    autofix: bool,
 ):
     pyproj_config = load_config(dir)
     if pyproj_config:
-        global_filter = GlobalFilter.create_from_config(pyproj_config)
-        global_filter.overwrite_from_cli(experimental, ignore, exclude)
+        global_settings = GlobalSettings.create_from_config(pyproj_config)
+        global_settings.overwrite_from_cli(experimental, ignore, exclude, autofix)
     else:
-        global_filter = GlobalFilter(experimental, ignore, exclude)
+        global_settings = GlobalSettings(experimental, ignore, exclude, autofix)
 
     if verbose:
         logger = logging.getLogger("tryceratops")
         logger.setLevel(logging.DEBUG)
 
     parsed_files = list(discovery.parse_python_files(dir))
-    runner.analyze(parsed_files, global_filter)
+    runner.analyze(parsed_files, global_settings)
 
     interface.present_and_exit()
 
