@@ -3,14 +3,16 @@ import importlib.metadata
 from tokenize import TokenInfo
 from typing import Any, Generator, Iterable, List, Tuple, Type
 
-from tryceratops.analyzers.main import Runner
 from tryceratops.files.discovery import load_config
 from tryceratops.files.parser import parse_ignore_tokens
-from tryceratops.filters import FileFilter, GlobalFilter
+from tryceratops.filters import FileFilter, GlobalSettings
+from tryceratops.runners import Runner
 from tryceratops.violations.violations import Violation
 
 PACKAGE_NAME = "tryceratops"
-GLOBAL_DUMMY_FILTER = GlobalFilter(False, ignore_violations=[], exclude_dirs=[])
+GLOBAL_DUMMY_FILTER = GlobalSettings(
+    include_experimental=False, ignore_violations=[], exclude_dirs=[], autofix=False
+)
 FLAKE8_VIOLATION_TYPE = Tuple[int, int, str, Type[Any]]
 # line, offset, message, class
 
@@ -31,12 +33,14 @@ class TryceratopsAdapterPlugin:
 
         ignore_lines = list(parse_ignore_tokens(file_tokens))
         self._file_filter = FileFilter(ignore_lines)
-        self._global_filter = self._create_global_filter(filename)
+        self._global_settings = self._create_global_settings(filename)
 
-    def _create_global_filter(self, filename: str) -> GlobalFilter:
+    def _create_global_settings(self, filename: str) -> GlobalSettings:
         pyproj_config = load_config([filename])
         if pyproj_config:
-            return GlobalFilter.create_from_config(pyproj_config)
+            filter = GlobalSettings.create_from_config(pyproj_config)
+            filter.autofix = False  # Do not allow this option for flake8 to avoid confusion
+            return filter
 
         return GLOBAL_DUMMY_FILTER
 
@@ -48,7 +52,7 @@ class TryceratopsAdapterPlugin:
                 self._file_filter,
             )
         ]
-        return self._runner.analyze(tryceratops_input, self._global_filter)
+        return self._runner.analyze(tryceratops_input, self._global_settings)
 
     def run(self) -> Generator[FLAKE8_VIOLATION_TYPE, None, None]:
         violations = self._execute_analyzer()
